@@ -8,10 +8,17 @@ Please find a description of this package at:
 
 Author: Ilan Schnell
 """
-__version__ = '0.3.2'
+__version__ = '0.3.3'
 
-from _bitarray import _bitarray, bits2bytes, _sysinfo
+try:
+    from _bitarray import _bitarray, bits2bytes, _sysinfo
+except ImportError:
+    raise ImportError("""No module named _bitarray
 
+Are you running python from the root of the bitarray source tree?
+If so, python is trying to import bitarray/_bitarray.so.
+To resolve this problem, change to another directory.
+""")
 
 class bitarray(_bitarray):
     """bitarray([initial][endian=string])
