@@ -46,13 +46,10 @@ static PyTypeObject Bitarraytype;
 
 /* ------------ Low level access to bits in bitarrayobject ------------- */
 
-static inline int
-getbit(bitarrayobject *self, idx_t i)
-{
-    return (self->ob_item[i / 8] & BITMASK(self->endian, i)) ? 1 : 0;
-}
+#define GETBIT(self, i)  \
+    ((self)->ob_item[(i) / 8] & BITMASK((self)->endian, i) ? 1 : 0)
 
-static inline void
+static void
 setbit(bitarrayobject *self, idx_t i, int bit)
 {
     char *cp, mask;
@@ -93,7 +90,7 @@ resize(bitarrayobject *self, idx_t nbits)
     if (check_overflow(nbits) < 0)
         return -1;
 
-    newsize = BYTES(nbits);
+    newsize = (Py_ssize_t) BYTES(nbits);
 
     /* Bypass realloc() when a previous overallocation is large enough
        to accommodate the newsize.  If the newsize is 16 smaller than the
@@ -150,7 +147,7 @@ newbitarrayobject(PyTypeObject *type, idx_t nbits, int endian)
     if (obj == NULL)
         return NULL;
 
-    nbytes = BYTES(nbits);
+    nbytes = (Py_ssize_t) BYTES(nbits);
     obj->ob_size = nbytes;
     obj->nbits = nbits;
     obj->endian = endian;
@@ -184,8 +181,8 @@ bitarray_dealloc(bitarrayobject *self)
 
 /* copy n bits from other (starting at b) onto self (starting at a) */
 static void
-bitcopy(bitarrayobject *self, idx_t a,
-        bitarrayobject *other, idx_t b, idx_t n)
+copy_n(bitarrayobject *self, idx_t a,
+       bitarrayobject *other, idx_t b, idx_t n)
 {
     /* XXX: This function could be highly optimized using memcpy for some
        cases when self and other have same endianness, and other != self.
@@ -200,24 +197,24 @@ bitcopy(bitarrayobject *self, idx_t a,
     /* the different type of looping is only relevant when other is self */
     if (a < b) {
         for (i = 0; i < n; i++)             /* loop forward (delete) */
-            setbit(self, i + a, getbit(other, i + b));
+            setbit(self, i + a, GETBIT(other, i + b));
     }
     else {
         for (i = n - 1; i >= 0; i--)      /* loop backwards (insert) */
-            setbit(self, i + a, getbit(other, i + b));
+            setbit(self, i + a, GETBIT(other, i + b));
     }
 }
 
 /* starting at start, delete n bits from self */
 static int
-delete(bitarrayobject *self, idx_t start, idx_t n)
+delete_n(bitarrayobject *self, idx_t start, idx_t n)
 {
     assert (start >= 0 && start <= self->nbits);
     assert (n >= 0 && start + n <= self->nbits);
     if (n == 0)
         return 0;
 
-    bitcopy(self, start, self, start + n, self->nbits - start);
+    copy_n(self, start, self, start + n, self->nbits - start);
     if (resize(self, self->nbits - n) < 0)
         return -1;
 
@@ -228,7 +225,7 @@ delete(bitarrayobject *self, idx_t start, idx_t n)
    The vaules of the inserted bits are unspecified.
 */
 static int
-insert(bitarrayobject *self, idx_t start, idx_t n)
+insert_n(bitarrayobject *self, idx_t start, idx_t n)
 {
     assert (start >= 0 && start <= self->nbits);
     assert (n >= 0);
@@ -238,7 +235,7 @@ insert(bitarrayobject *self, idx_t start, idx_t n)
     if (resize(self, self->nbits + n) < 0)
         return -1;
 
-    bitcopy(self, start + n, self, start, self->nbits - start);
+    copy_n(self, start + n, self, start, self->nbits - start);
     return 0;
 }
 
@@ -274,7 +271,7 @@ repeat(bitarrayobject *self, idx_t n)
             return -1;
 
         for (i = 1; i < n; i++)
-            bitcopy(self, i * nbits, self, 0, nbits);
+            copy_n(self, i * nbits, self, 0, nbits);
     }
     return 0;
 }
@@ -340,6 +337,9 @@ bytereverse(bitarrayobject *self)
 {
     static char trans[256];
     static int setup = 0;
+    Py_ssize_t i;
+    int c;
+
     if (!setup) {
         /* Setup a translation table, which maps each byte to it's
            reversed: trans = {0, 128, 64, 192, 32, 160, ..., 255}
@@ -353,8 +353,6 @@ bytereverse(bitarrayobject *self)
         }
         setup = 1;
     }
-    Py_ssize_t i;
-    int c;
 
     setunused(self);
     for (i = 0; i < self->ob_size; i++) {
@@ -380,6 +378,10 @@ count(bitarrayobject *self)
 {
     static int bitcount[256];
     static int setup = 0;
+    Py_ssize_t i;
+    idx_t res = 0;
+    int c;
+
     if (!setup) {
         /* Setup a translation table, which maps each byte to it's
            bit count: trans = {0, 1, 1, 2, 1, 2, 2, 3, 1, ..., 8}
@@ -392,9 +394,6 @@ count(bitarrayobject *self)
         }
         setup = 1;
     }
-    idx_t res = 0;
-    Py_ssize_t i;
-    int c;
 
     setunused(self);
     for (i = 0; i < self->ob_size; i++) {
@@ -429,7 +428,7 @@ findfirst(bitarrayobject *self, int vi)
 
     /* fine graded search within byte */
     for (i = BITS(j); i < self->nbits; i++)
-        if (getbit(self, i) == vi)
+        if (GETBIT(self, i) == vi)
             return i;
 
     return -1;
@@ -474,9 +473,9 @@ unpack(bitarrayobject *self, char zero, char one)
         return NULL;
     }
     for (i = 0; i < self->nbits; i++) {
-        *(str + i) = getbit(self, i) ? one : zero;
+        *(str + i) = GETBIT(self, i) ? one : zero;
     }
-    res = PyString_FromStringAndSize(str, self->nbits);
+    res = PyString_FromStringAndSize(str, (Py_ssize_t) self->nbits);
     PyMem_Free((void *) str);
     return res;
 }
@@ -493,7 +492,7 @@ extend_bitarray(bitarrayobject *self, bitarrayobject *other)
     if (resize(self, sumbits) < 0)
         return -1;
 
-    bitcopy(self, sumbits - other->nbits, other, 0, other->nbits);
+    copy_n(self, sumbits - other->nbits, other, 0, other->nbits);
     return 0;
 }
 
@@ -809,6 +808,8 @@ It is an error when x does not occur in the bitarray");
 static PyObject *
 bitarray_extend(bitarrayobject *self, PyObject *obj)
 {
+    PyObject *iter;
+
     /* dispatch on type */
     if (bitarray_Check(obj)) {                            /* bitarray */
         if (extend_bitarray(self, (bitarrayobject *) obj) < 0)
@@ -835,9 +836,8 @@ bitarray_extend(bitarrayobject *self, PyObject *obj)
             return NULL;
         Py_RETURN_NONE;
     }
-    /* finally, try to get the iterator of the object */
-    PyObject *iter;
 
+    /* finally, try to get the iterator of the object */
     if ((iter = PyObject_GetIter(obj)) == NULL) {
         PyErr_SetString(PyExc_TypeError, "could not extend bitarray");
         return NULL;
@@ -872,41 +872,41 @@ bitarray_search(bitarrayobject *self, PyObject *args)
         return NULL;
 
     if (bitarray_Check(x)) {
-	xa = (bitarrayobject *) x;
+        xa = (bitarrayobject *) x;
     }
     else {
-	xa = (bitarrayobject *) newbitarrayobject(self->ob_type, 0,
-						  self->endian);
-	if (xa == NULL)
-	    return NULL;
+        xa = (bitarrayobject *) newbitarrayobject(self->ob_type, 0,
+                                                  self->endian);
+        if (xa == NULL)
+            return NULL;
 
-	if (bitarray_extend(xa, x) == NULL)
-	    return NULL;
+        if (bitarray_extend(xa, x) == NULL)
+            return NULL;
     }
 
     if (xa->nbits == 0) {
-	PyErr_SetString(PyExc_TypeError, "can't search for empty bitarray");
-	return NULL;
+        PyErr_SetString(PyExc_TypeError, "can't search for empty bitarray");
+        return NULL;
     }
 
     list = PyList_New(0);
     if (xa->nbits > self->nbits)
-	return list;
+        return list;
 
     for (p = 0; p < self->nbits - xa->nbits + 1; p++) {
-	match = 1;
-	for (n = 0; n < xa->nbits; n++) {
-	    if (getbit(self, p + n) != getbit(xa, n)) {
-		match = 0;
-		break;
-	    }
-	}
-	if (match && PyList_Append(list, PyLong_FromLongLong(p)) < 0) {
-	    Py_DECREF(list);
-	    return NULL;
-	}
-	if (limit >= 0 && PyList_Size(list) >= limit)
-	    break;
+        match = 1;
+        for (n = 0; n < xa->nbits; n++) {
+            if (GETBIT(self, p + n) != GETBIT(xa, n)) {
+                match = 0;
+                break;
+            }
+        }
+        if (match && PyList_Append(list, PyLong_FromLongLong(p)) < 0) {
+            Py_DECREF(list);
+            return NULL;
+        }
+        if (limit >= 0 && PyList_Size(list) >= limit)
+            break;
     }
     return list;
 }
@@ -928,15 +928,15 @@ bitarray_contains(bitarrayobject *self, PyObject *v)
 
     if (PyInt_Check(v)) {
         if (findfirst(self, PyInt_AS_LONG(v)) >= 0)
-	    res = 1;
+            res = 1;
     }
     else {
-	list = bitarray_search(self, Py_BuildValue("Oi", v, 1));
-	if (list == NULL)
-	    return NULL;
+        list = bitarray_search(self, Py_BuildValue("Oi", v, 1));
+        if (list == NULL)
+            return NULL;
 
-	if (PyList_Size(list) > 0)
-	    res = 1;
+        if (PyList_Size(list) > 0)
+            res = 1;
     }
     return PyBool_FromLong(res);
 }
@@ -1074,11 +1074,11 @@ bitarray_reverse(bitarrayobject *self)
 
     /* Reverse the upper half onto the lower half. */
     for (i = 0; i < tt->nbits; i++)
-        setbit(self, i, getbit(self, m - i));
+        setbit(self, i, GETBIT(self, m - i));
 
     /* Revert the stored away lower half onto the upper half. */
     for (i = 0; i < tt->nbits; i++)
-        setbit(self, m - i, getbit(tt, i));
+        setbit(self, m - i, GETBIT(tt, i));
 #undef tt
     Py_DECREF(t);
     Py_RETURN_NONE;
@@ -1192,8 +1192,10 @@ static PyObject *
 bitarray_fromfile(bitarrayobject *self, PyObject *args)
 {
     PyObject *f;
-    Py_ssize_t nbytes = -1;
     FILE *fp;
+    Py_ssize_t newsize, nbytes = -1;
+    size_t nread;
+    idx_t t, p;
     long cur;
 
     if (!PyArg_ParseTuple(args, "O|n:fromfile", &f, &nbytes))
@@ -1225,10 +1227,6 @@ bitarray_fromfile(bitarrayobject *self, PyObject *args)
         Py_RETURN_NONE;
 
     /* File exists and there are more than zero bytes to read */
-    Py_ssize_t newsize;
-    size_t nread;
-    idx_t t, p;
-
     t = self->nbits;
     p = setunused(self);
     self->nbits += p;
@@ -1238,7 +1236,7 @@ bitarray_fromfile(bitarrayobject *self, PyObject *args)
         return NULL;
 
     nread = fread(self->ob_item + (self->ob_size - nbytes), 1, nbytes, fp);
-    if (nread < nbytes) {
+    if (nread < (size_t) nbytes) {
         newsize -= nbytes - nread;
         if (resize(self, BITS(newsize)) < 0)
             return NULL;
@@ -1246,7 +1244,7 @@ bitarray_fromfile(bitarrayobject *self, PyObject *args)
         return NULL;
     }
 
-    delete(self, t, p);
+    delete_n(self, t, p);
     Py_RETURN_NONE;
 }
 
@@ -1295,12 +1293,12 @@ bitarray_tolist(bitarrayobject *self)
     PyObject *list;
     idx_t i;
 
-    if ((list = PyList_New(self->nbits)) == NULL)
+    if ((list = PyList_New((Py_ssize_t) self->nbits)) == NULL)
         return NULL;
 
     for (i = 0; i < self->nbits; i++)
-        PyList_SetItem(list, i, PyBool_FromLong(getbit(self, i)));
-
+        PyList_SetItem(list, (Py_ssize_t) i,
+                       PyBool_FromLong(GETBIT(self, i)));
     return list;
 }
 
@@ -1328,7 +1326,7 @@ bitarray_fromstring(bitarrayobject *self, PyObject *string)
     if (extend_rawstring(self, string) < 0)
         return NULL;
 
-    delete(self, t, p);
+    delete_n(self, t, p);
     Py_RETURN_NONE;
 }
 
@@ -1446,7 +1444,7 @@ bitarray_insert(bitarrayobject *self, PyObject *args)
     if (i >= self->nbits)
         i = self->nbits;
 
-    if (insert(self, i, 1) < 0)
+    if (insert_n(self, i, 1) < 0)
         return NULL;
 
     set_item(self, i, v);
@@ -1480,8 +1478,8 @@ bitarray_pop(bitarrayobject *self, PyObject *args)
         PyErr_SetString(PyExc_IndexError, "pop index out of range");
         return NULL;
     }
-    tmp = getbit(self, i);
-    if (delete(self, i, 1) < 0)
+    tmp = GETBIT(self, i);
+    if (delete_n(self, i, 1) < 0)
         return NULL;
     return PyBool_FromLong(tmp);
 }
@@ -1507,7 +1505,7 @@ bitarray_remove(bitarrayobject *self, PyObject *v)
         PyErr_SetString(PyExc_ValueError, "remove(x): x not in bitarray");
         return NULL;
     }
-    if (delete(self, i, 1) < 0)
+    if (delete_n(self, i, 1) < 0)
         return NULL;
     Py_RETURN_NONE;
 }
@@ -1524,7 +1522,7 @@ static PyObject *
 bitarray_getitem(bitarrayobject *self, PyObject *a)
 {
     PyObject *res;
-    idx_t start, stop, step, slicelength, i, j;
+    idx_t start, stop, step, slicelength, j, i = 0;
 
     if (ISINDEX(a)) {
         getIndex(a, &i);
@@ -1536,7 +1534,7 @@ bitarray_getitem(bitarrayobject *self, PyObject *a)
             PyErr_SetString(PyExc_IndexError, "bitarray index out of range");
             return NULL;
         }
-        return PyBool_FromLong(getbit(self, i));
+        return PyBool_FromLong(GETBIT(self, i));
     }
     if (PySlice_Check(a)) {
         if(slice_GetIndicesEx((PySliceObject *) a, self->nbits,
@@ -1548,7 +1546,7 @@ bitarray_getitem(bitarrayobject *self, PyObject *a)
             return NULL;
 
         for (i = 0, j = start; i < slicelength; i++, j += step)
-            setbit((bitarrayobject *) res, i, getbit(self, j));
+            setbit((bitarrayobject *) res, i, GETBIT(self, j));
 
         return res;
     }
@@ -1560,7 +1558,7 @@ static PyObject *
 bitarray_setitem(bitarrayobject *self, PyObject *args)
 {
     PyObject *a, *v;
-    idx_t start, stop, step, slicelength, i, j;
+    idx_t start, stop, step, slicelength, j, i = 0;
 
     if (!PyArg_ParseTuple(args, "OO:__setitem__", &a, &v))
         return NULL;
@@ -1591,7 +1589,7 @@ bitarray_setitem(bitarrayobject *self, PyObject *args)
 #define vv  ((bitarrayobject *) v)
         if (vv->nbits == slicelength) {
             for (i = 0, j = start; i < slicelength; i++, j += step)
-                setbit(self, j, getbit(vv, i));
+                setbit(self, j, GETBIT(vv, i));
             Py_RETURN_NONE;
         }
         if (step != 1) {
@@ -1605,15 +1603,15 @@ bitarray_setitem(bitarrayobject *self, PyObject *args)
         }
         /* make self bigger or smaller */
         if (vv->nbits > slicelength) {
-            if (insert(self, start, vv->nbits - slicelength) < 0)
+            if (insert_n(self, start, vv->nbits - slicelength) < 0)
                 return NULL;
         }
         else {
-            if (delete(self, start, slicelength - vv->nbits) < 0)
+            if (delete_n(self, start, slicelength - vv->nbits) < 0)
                 return NULL;
         }
         /* copy the new values into self */
-        bitcopy(self, start, vv, 0, vv->nbits);
+        copy_n(self, start, vv, 0, vv->nbits);
         Py_RETURN_NONE;
 #undef vv
     }
@@ -1624,7 +1622,7 @@ bitarray_setitem(bitarrayobject *self, PyObject *args)
 static PyObject *
 bitarray_delitem(bitarrayobject *self, PyObject *a)
 {
-    idx_t start, stop, step, slicelength, i, j;
+    idx_t start, stop, step, slicelength, j, i = 0;
 
     if (ISINDEX(a)) {
         getIndex(a, &i);
@@ -1637,7 +1635,7 @@ bitarray_delitem(bitarrayobject *self, PyObject *a)
                             "bitarray assignment index out of range");
             return NULL;
         }
-        if (delete(self, i, 1) < 0)
+        if (delete_n(self, i, 1) < 0)
             return NULL;
         Py_RETURN_NONE;
     }
@@ -1656,14 +1654,14 @@ bitarray_delitem(bitarrayobject *self, PyObject *a)
         }
         if (step == 1) {
             assert (stop - start == slicelength);
-            if (delete(self, start, slicelength) < 0)
+            if (delete_n(self, start, slicelength) < 0)
                 return NULL;
             Py_RETURN_NONE;
         }
         /* This is the only complicated part when step > 1 */
         for (i = j = start; i < self->nbits; i++)
             if ((i - start) % step != 0 || i >= stop)
-                setbit(self, j++, getbit(self, i));
+                setbit(self, j++, GETBIT(self, i));
         if (resize(self, self->nbits - slicelength) < 0)
             return NULL;
         Py_RETURN_NONE;
@@ -1700,7 +1698,7 @@ static PyObject *
 bitarray_mul(bitarrayobject *self, PyObject *v)
 {
     PyObject *res;
-    idx_t vi;
+    idx_t vi = 0;
 
     if (!ISINDEX(v)) {
         PyErr_SetString(PyExc_TypeError,
@@ -1718,7 +1716,7 @@ bitarray_mul(bitarrayobject *self, PyObject *v)
 static PyObject *
 bitarray_imul(bitarrayobject *self, PyObject *v)
 {
-    idx_t vi;
+    idx_t vi = 0;
 
     if (!ISINDEX(v)) {
         PyErr_SetString(PyExc_TypeError,
@@ -1833,7 +1831,7 @@ bitarray_encode(bitarrayobject *self, PyObject *args)
         }
         Py_DECREF(symbol);
         if (bitarray_extend(self, bits) == NULL)
-	    return NULL;
+            return NULL;
     }
     Py_DECREF(iter);
     if (PyErr_Occurred())
@@ -1911,7 +1909,7 @@ btree_insert(PyObject *tree, PyObject *symbol, PyObject *b)
     int ret, vi;
 
     bb = (bitarrayobject *) b;
-    vi = getbit(bb, 0);
+    vi = GETBIT(bb, 0);
     if (bb->nbits > 1) {
         /* create new subtree if necessary */
         if (IS_EMPTY_LIST(PyList_GetItem(tree, vi))) {
@@ -1923,7 +1921,7 @@ btree_insert(PyObject *tree, PyObject *symbol, PyObject *b)
         /* a = b[1:] */
         if ((a = bitarray_copy(bb)) == NULL)
             return -1;
-        delete((bitarrayobject *) a, 0, 1);
+        delete_n((bitarrayobject *) a, 0, 1);
         /* insert symbol */
         ret = btree_insert(PyList_GetItem(tree, vi), symbol, a);
         Py_DECREF(a);
@@ -2094,7 +2092,9 @@ bitarray_methods[] = {
 static PyObject *
 bitarray_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
+    PyObject *a;  /* to be returned in some cases */
     PyObject *initial = NULL;
+    idx_t nbits = 0;
     char *endianStr = "<NOT_PROVIDED>";
     int endian = DEFAULT_ENDIAN;
     static char* kwlist[] = {"initial", "endian", NULL};
@@ -2124,7 +2124,6 @@ bitarray_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     /* int, long */
     if (ISINDEX(initial)) {
-        idx_t nbits;
         getIndex(initial, &nbits);
 
         if (nbits < 0) {
@@ -2134,7 +2133,6 @@ bitarray_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
         }
         return newbitarrayobject(type, nbits, endian);
     }
-    PyObject *a;  /* to be returned */
 
     /* from bitarray itself */
     if (bitarray_Check(initial)) {
@@ -2185,8 +2183,8 @@ richcompare(PyObject *v, PyObject *w, int op)
     /* Search for the first index where items are different */
     k = 1;
     for (i = 0; i < va->nbits && i < wa->nbits; i++) {
-        vi = getbit(va, i);
-        wi = getbit(wa, i);
+        vi = GETBIT(va, i);
+        wi = GETBIT(wa, i);
         k = (vi == wi);
         if (k == 0)
             break;
@@ -2268,7 +2266,7 @@ bitarrayiter_next(bitarrayiterobject *it)
 {
     assert (BitarrayIter_Check(it));
     if (it->index < it->bao->nbits)
-        return PyBool_FromLong(getbit(it->bao, it->index++));
+        return PyBool_FromLong(GETBIT(it->bao, it->index++));
 
     return NULL;
 }
@@ -2373,7 +2371,7 @@ static PyTypeObject Bitarraytype = {
 static PyObject *
 bits2bytes(PyObject *self, PyObject *v)
 {
-    idx_t n;
+    idx_t n = 0;
 
     if (ISINDEX(v)) {
         getIndex(v, &n);
